@@ -105,7 +105,7 @@ class BaseSnatch:
         return self._format_timeout_response("/last_prospect")
 
     def _post_new_prospect(self, timeout: int) -> BaseData:
-        url = "/api/prospects/from_tax_id"
+        url = "/api/prospects/from_tax_id/"
         payload = {"tax_id": self.tax_id}
         data = self._request_and_create_data(url=url, timeout=timeout, payload=payload)
         return data
