@@ -52,7 +52,19 @@ class SecretManager:
         return self._client
 
     def _get_available_secrets(self) -> List[str]:
-        all_secrets = self.client.list_secrets()
+        all_secrets = self.client.list_secrets(
+            all_secrets=self.client.list_secrets(
+                MaxResults=100,
+                Filters=[
+                    {
+                        "Key": "name",
+                        "Values": [
+                            "snatch",
+                        ],
+                    },
+                ],
+            )
+        )
 
         all_keys = [
             secret["Name"]
